@@ -1,6 +1,6 @@
 package Map::Tube::Route;
 
-$Map::Tube::Route::VERSION   = '2.96';
+$Map::Tube::Route::VERSION   = '2.97';
 $Map::Tube::Route::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::Route - Class to represent the route in the map.
 
 =head1 VERSION
 
-Version 2.96
+Version 2.97
 
 =cut
 
@@ -47,27 +47,50 @@ from "start" to "end" station.
 
 =head2 preferred()
 
-Returns preferred route as string.
+Returns an object of type L<Map::Tube::Route> as preferred route.
 
 =cut
 
 sub preferred {
     my ($self) = @_;
 
+    my $index = 0;
     my $nodes = [];
     my $lines = [];
+    my $nodes_object = {};
+    my $lines_object = {};
     foreach my $node (@{$self->nodes}) {
         push @$nodes, { name => $node->name };
-        push @$lines, [ map { $_->name } @{$node->{line}} ];
+        $nodes_object->{$node->name} = $node;
+
+        foreach my $line (@{$node->{line}}) {
+            push @{$lines->[$index]}, $line->name;
+            $lines_object->{$line->name} = $line;
+        }
+
+        $index++;
     }
 
-    my $data  = filter($lines);
-    my $route = [];
-    for my $i (0..$#$nodes) {
-        push @$route, sprintf("%s (%s)", $nodes->[$i]->{name}, join(", ", @{$data->[$i]}));
+    my $data   = filter($lines);
+    my $_nodes = [];
+    foreach my $i (0..$#$nodes) {
+        my $_node = {
+            id   => $nodes_object->{$nodes->[$i]->{name}}->id,
+            name => $nodes->[$i]->{name},
+            link => $nodes_object->{$nodes->[$i]->{name}}->link,
+        };
+
+        foreach (@{$data->[$i]}) {
+            push @{$_node->{line}}, $lines_object->{$_};
+        }
+
+        push @$_nodes, Map::Tube::Node->new($_node);
     }
 
-    return join(", ", @$route);
+    return Map::Tube::Route->new({
+        from  => $self->from,
+        to    => $self->to,
+        nodes => $_nodes });
 }
 
 sub as_string {
